BindInject<T extends Object> class

Inheritance

Constructors

BindInject(T factoryFunction(Injector i), {bool isSingleton = true, bool isLazy = true, bool isScoped = true, void onDispose(T value)?})

Properties

alwaysSerialized → bool
flag for indicate serialization
finalinherited
bindType → Type
no setterinherited
export → bool
export bind for others modules This bind can only be accessed when imported by a module.
finalinherited
factoryFunction → T Function(Injector i)
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
inject ↔ T Function(Injector i)
latefinal
isLazy → bool
When 'true', the object is instantiated only the first time it is called. When 'false', the object is instantiated along with the module.
finalinherited
isScoped → bool
create single instance for request
finalinherited
isSingleton → bool
single instance
finalinherited
onDispose → void Function(T value)?
Called in module`s dispose.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selector → dynamic Function(T value)?
Generate reactive object
finalinherited

Methods

cast<E extends Object>() → BindContract<E>
inherited
copyWith({T factoryFunction(Injector i)?, bool? isSingleton, bool? isLazy, bool? export, bool? isScoped, bool? alwaysSerialized, void onDispose(T value)?, dynamic selector(T value)?}) → BindContract<T>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDisposeFunc(Object o) → dynamic
inherited
onSelectorFunc(Object o) → dynamic
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited