ModularRoute class abstract

Represents a route within a RouteContext.

Implementers

Constructors

ModularRoute()

Properties

bindContextEntries → Map<Type, BindContext>
Contains a list of all BindContexts that will need to be active when this route is active.
no setter
children → List<ModularRoute>
Add children to this route that can be retrieved through the parent route
no setter
context → RouteContext?
RouteContext belonging to the route.
no setter
hashCode → int
The hash code for this object.
no setterinherited
key → ModularKey
Key that references the route in the RouteContext tree.
no setter
middlewares → List<Middleware>
Adds middleware that will be shared among your children.
no setter
name → String
name of route
no setter
parent → String
guard your parent's path
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema → String
schema of route default is ''
no setter
uri → Uri
Current uri of the route.
no setter

Methods

addModule(String name, {required RouteContext module}) → ModularRoute
Create a new Route by adding a RouteContext to the context.
copyWith({String? name, List<Middleware>? middlewares, List<ModularRoute>? children, String? parent, String? schema, RouteContext? context, Uri? uri, Map<ModularKey, ModularRoute>? routeMap, Map<Type, BindContext>? bindContextEntries}) → ModularRoute
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited