Module class

/// A Module gathers all Binds and Routes referring to this context. They are usually distributed in the form of features or a monolithic representation of the app. At least one module is needed to start a Modular project.

Constructors

Module()

Properties

binds → List<Bind<Object>>
Link injected objects
no setter
hashCode → int
The hash code for this object.
no setterinherited
imports → List<Module>
Import Binds from other modules. ATTENTION: The binds must be marked with the flag export: true, in the module to be imported.
no setter
instanciatedSingletons → List<BindEntry<Object>>
Bind ready as singleton
no setterinherited
modules → List<RouteContext>
finalinherited
routes → List<ModularRoute>
Aggregates all ModularRoute type Objects to the context,
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addChildren(ModularRoute route) → Map<ModularKey, ModularRoute>
inherited
addModule(ModularRoute route) → Map<ModularKey, ModularRoute>
inherited
assembleRoute(ModularRoute route) → Map<ModularKey, ModularRoute>
inherited
changeBinds(List<BindContract<Object>> newBinds) → void
Change binds
inherited
copy(ModularRoute parent, ModularRoute route) → ModularRoute
inherited
dispose() → void
Dispose all bind from the memory
inherited
getBind<T extends Object>(Injector injector) → BindEntry<T>?
Get the binds for that context.
inherited
getProcessBinds() → List<BindContract<Object>>
get processed binds
inherited
init() → Map<ModularKey, ModularRoute>
Used to return a route map at the start of the application.
inherited
instantiateSingletonBinds(List<BindEntry<Object>> singletons, Injector injector) → void
inherited
isReady() → Future<void>
checks if all asynchronous binds are ready to be used synchronously.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
orderRouteKeys(Iterable<ModularKey> keys) → List<ModularKey>
inherited
remove<T>() → bool
Dispose bind from the memory
inherited
removeScopedBind() → bool
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited